@@ -382,7 +382,7 @@ def add_new_record(_add_value, _class, func=None):
     return add(_add_value)
 
 
-def add_cornjob_task(_add_value, func=None):
+def add_cronjob_task(_add_value, func=None):
     return add_new_record(_add_value, CronjobTask, func=func)
 
 
@@ -659,18 +659,18 @@ if __name__ == '__main__':
     if not init(cfg):
         logger.warning(f"not init()")
     else:
-        new_cornjob_task = {'schedule': '*/1 * * * *',
+        new_cronjob_task = {'schedule': '*/1 * * * *',
                             'module': 'Modules.TestTasks',
                             'func': 'raise_exception',  # raise_exception, sleep_false, sleep
                             'params': {"counter": 4},
                             'project': 'project_2',
                             'max_retry_count': 2,
                             'enabled': True}
-        # new_cornjob_task = CronjobTask(**new_cornjob_task)
+        # new_cronjob_task = CronjobTask(**new_cronjob_task)
         # from Modules import TestTasks
-        # new_cornjob_task = add_cornjob_task(new_cornjob_task, TestTasks.raise_exception)
-        new_cornjob_task = add_cornjob_task(new_cornjob_task)
-        print(f'new_cornjob_task: {new_cornjob_task}')
+        # new_cronjob_task = add_cronjob_task(new_cronjob_task, TestTasks.raise_exception)
+        new_cronjob_task = add_cronjob_task(new_cronjob_task)
+        print(f'new_cronjob_task: {new_cronjob_task}')
 
         import datetime
         new_task = {'module': 'Modules.TestTasks',
